pub struct GitTools { /* private fields */ }Expand description
Git operations service
Implementations
Sourceimpl GitTools
impl GitTools
pub fn new(work_dir: Option<PathBuf>) -> Self
Sourcepub fn with_work_dir(self, dir: PathBuf) -> Self
pub fn with_work_dir(self, dir: PathBuf) -> Self
Set working directory
Sourcepub fn rev_parse_toplevel(&self) -> Result<PathBuf>
pub fn rev_parse_toplevel(&self) -> Result<PathBuf>
Resolve the repository top-level path.
Sourcepub fn current_branch(&self) -> Result<String>
pub fn current_branch(&self) -> Result<String>
Return the current branch name.
Sourcepub fn branch_exists(&self, branch: &str) -> Result<bool>
pub fn branch_exists(&self, branch: &str) -> Result<bool>
Check whether a local branch exists.
Sourcepub fn path_is_git_repo(&self) -> Result<bool>
pub fn path_is_git_repo(&self) -> Result<bool>
Check whether the current working directory is inside a git repository.
Sourcepub fn worktree_list(&self) -> Result<Vec<GitWorktreeInfo>>
pub fn worktree_list(&self) -> Result<Vec<GitWorktreeInfo>>
List all worktrees for the repository.
Sourcepub fn worktree_add(
&self,
path: &Path,
branch: &str,
base_branch: &str,
create_branch: bool,
) -> Result<GitWorktreeInfo>
pub fn worktree_add( &self, path: &Path, branch: &str, base_branch: &str, create_branch: bool, ) -> Result<GitWorktreeInfo>
Create a worktree for an existing or new branch.
Sourcepub fn worktree_prune(&self) -> Result<()>
pub fn worktree_prune(&self) -> Result<()>
Prune stale worktree metadata.
Sourcepub fn is_worktree_clean(&self, path: &Path) -> Result<bool>
pub fn is_worktree_clean(&self, path: &Path) -> Result<bool>
Check whether a worktree has uncommitted changes.
Sourcepub fn diff(&self, staged: bool, path: Option<&Path>) -> Result<String>
pub fn diff(&self, staged: bool, path: Option<&Path>) -> Result<String>
Get diff (staged or unstaged)